@@ -18,6 +18,9 @@ def make_camel_case(string):
     for index, word in enumerate(string.split(" ")):
         uppercase_char_count = 0
 
+        if word.startswith("https://") or word.startswith("www."):
+            continue
+
         for char in word:
             if char.isupper():
                 uppercase_char_count += 1
